import { Instruction } from "@orca-so/common-sdk";
import { PublicKey } from "@solana/web3.js";
import { BN, Program } from "@coral-xyz/anchor";
import { Staking } from "../artifacts/staking";

export type WithdrawParams = {
  accounts: {
    user: PublicKey;
  };
  inputs: {
    withdrawPositionBump: number;
    index: number;
    amount: BN;
  };
};

export async function withdraw(
  program: Program<Staking>,
  params: WithdrawParams,
): Promise<Instruction> {
  const { accounts, inputs } = params;

  const ix = await program.methods
    .withdraw(inputs.withdrawPositionBump, inputs.index, inputs.amount)
    .accounts({
      ...accounts,
    })
    .instruction();

  return {
    instructions: [ix],
    cleanupInstructions: [],
    signers: [],
  };
}
